==> okteta-0.26.0.tar.xz: okteta-0.26.0/kasten/controllers/view/replace/replaceprompt.hpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2006-2007,2009,2013 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KASTEN_REPLACEPROMPT_HPP
#define KASTEN_REPLACEPROMPT_HPP

// controller
#include "replaceuserqueryable.hpp"
// Qt
#include <QDialog>

class QEventLoop;

namespace Kasten {

class ReplacePrompt : public QDialog
{
    Q_OBJECT

public:
    explicit ReplacePrompt(QWidget* parent);

public:
    ReplaceBehaviour query();

private Q_SLOTS:
    void onReplaceAllButton();
    void onSkipButton();
    void onReplaceButton();
    void onCloseButton();

private:
    QEventLoop* mEventLoop;

    ReplaceBehaviour mResult;
};

}

#endif

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/replace/replaceprompt.hpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2006-2007,2009,2013 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KASTEN_REPLACEPROMPT_HPP
#define KASTEN_REPLACEPROMPT_HPP

// controller
#include "replaceuserqueryable.hpp"
// Qt
#include <QDialog>

namespace Kasten {

class ReplacePrompt : public QDialog
{
    Q_OBJECT

public:
    explicit ReplacePrompt(QWidget* parent);

Q_SIGNALS:
    void finished(Kasten::ReplaceBehaviour behaviour);

private Q_SLOTS:
    void onReplaceAllButton();
    void onSkipButton();
    void onReplaceButton();
    void onCloseButton();
};

}

#endif
